==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/compat/sodium/SodiumCompat.java <==
package com.zurrtum.create.client.compat.sodium;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.client.AllFluidConfigs;
import com.zurrtum.create.client.Create;
import com.zurrtum.create.client.infrastructure.fluid.FluidConfig;
import com.zurrtum.create.client.ponder.api.level.PonderLevel;
import com.zurrtum.create.client.ponder.api.scene.Selection;
import com.zurrtum.create.content.fluids.tank.FluidTankBlock;
import com.zurrtum.create.content.fluids.tank.FluidTankBlockEntity;
import com.zurrtum.create.infrastructure.fluids.FluidStack;
import net.caffeinemc.mods.sodium.api.texture.SpriteUtil;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1058;
import net.minecraft.class_1059;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import java.util.HashSet;
import java.util.Set;
import java.util.function.Function;

/**
 * Fixes the Mechanical Saw's sprite and Factory Gauge's sprite
 */
public class SodiumCompat {
    private static final boolean DISABLE = !FabricLoader.getInstance().isModLoaded("sodium");
    public static final class_2960 SAW_TEXTURE = Create.asResource("block/saw_reversed");
    public static final class_2960 FACTORY_PANEL_TEXTURE = Create.asResource("block/factory_panel_connections_animated");
    public static final class_2960 SAW_VANILLA_TEXTURE = class_2960.method_60656("block/stonecutter_saw");

    @SuppressWarnings({"UnstableApiUsage", "deprecation"})
    public static void markSpriteActive(class_310 mc) {
        if (DISABLE) {
            return;
        }
        Function<class_2960, class_1058> atlas = mc.method_1549(class_1059.field_5275);
        SpriteUtil.INSTANCE.markSpriteActive(atlas.apply(SAW_TEXTURE));
        SpriteUtil.INSTANCE.markSpriteActive(atlas.apply(SAW_VANILLA_TEXTURE));
        SpriteUtil.INSTANCE.markSpriteActive(atlas.apply(FACTORY_PANEL_TEXTURE));
    }

    @SuppressWarnings({"UnstableApiUsage", "deprecation"})
    public static void markPonderSpriteActive(PonderLevel world, Selection section) {
        if (DISABLE) {
            return;
        }
        boolean saw = true;
        boolean panel = true;
        Set<class_3611> fluids = new HashSet<>();
        for (class_2338 pos : section) {
            class_2680 state = world.method_8320(pos);
            if (state.method_26215()) {
                continue;
            }
            if (saw && state.method_27852(AllBlocks.MECHANICAL_SAW)) {
                Function<class_2960, class_1058> atlas = class_310.method_1551().method_1549(class_1059.field_5275);
                SpriteUtil.INSTANCE.markSpriteActive(atlas.apply(SAW_TEXTURE));
                SpriteUtil.INSTANCE.markSpriteActive(atlas.apply(SAW_VANILLA_TEXTURE));
                saw = false;
                continue;
            }
            if (panel && state.method_27852(AllBlocks.FACTORY_GAUGE)) {
                SpriteUtil.INSTANCE.markSpriteActive(class_310.method_1551().method_1549(class_1059.field_5275)
                    .apply(FACTORY_PANEL_TEXTURE));
                panel = false;
                continue;
            }
            if (state.method_26204() instanceof FluidTankBlock && world.method_8321(pos) instanceof FluidTankBlockEntity tank) {
                FluidStack stack = tank.getTankInventory().getFluid();
                if (stack.isEmpty()) {
                    continue;
                }
                class_3611 fluid = stack.getFluid();
                if (fluids.add(fluid)) {
                    markFluidSpriteActive(fluid);
                }
                continue;
            }
            class_3610 fluidState = state.method_26227();
            if (!fluidState.method_15769()) {
                class_3611 fluid = fluidState.method_15772();
                if (fluids.add(fluid)) {
                    markFluidSpriteActive(fluid);
                }
            }
        }
    }

    @SuppressWarnings("UnstableApiUsage")
    public static void markFluidSpriteActive(class_3611 fluid) {
        if (DISABLE) {
            return;
        }
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            SpriteUtil.INSTANCE.markSpriteActive(config.still().get());
            SpriteUtil.INSTANCE.markSpriteActive(config.flowing().get());
        }
    }
}

==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/client/compat/sodium/SodiumCompat.java <==
package com.zurrtum.create.client.compat.sodium;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.client.AllFluidConfigs;
import com.zurrtum.create.client.Create;
import com.zurrtum.create.client.infrastructure.fluid.FluidConfig;
import com.zurrtum.create.client.ponder.api.level.PonderLevel;
import com.zurrtum.create.client.ponder.api.scene.Selection;
import com.zurrtum.create.content.fluids.tank.FluidTankBlock;
import com.zurrtum.create.content.fluids.tank.FluidTankBlockEntity;
import com.zurrtum.create.infrastructure.fluids.FluidStack;
import net.caffeinemc.mods.sodium.api.texture.SpriteUtil;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1059;
import net.minecraft.class_11697;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_4730;
import java.util.HashSet;
import java.util.Set;

/**
 * Fixes the Mechanical Saw's sprite and Factory Gauge's sprite
 */
@SuppressWarnings("deprecation")
public class SodiumCompat {
    private static final boolean DISABLE = !FabricLoader.getInstance().isModLoaded("sodium");
    public static final class_4730 SAW_TEXTURE = new class_4730(
        class_1059.field_5275,
        Create.asResource("block/saw_reversed")
    );
    public static final class_4730 FACTORY_PANEL_TEXTURE = new class_4730(
        class_1059.field_5275,
        Create.asResource("block/factory_panel_connections_animated")
    );
    public static final class_4730 SAW_VANILLA_TEXTURE = new class_4730(
        class_1059.field_5275,
        class_2960.method_60656("block/stonecutter_saw")
    );

    @SuppressWarnings("UnstableApiUsage")
    public static void markSpriteActive(class_310 mc) {
        if (DISABLE) {
            return;
        }
        class_11697 atlasManager = mc.method_72703();
        SpriteUtil.INSTANCE.markSpriteActive(atlasManager.method_73030(SAW_TEXTURE));
        SpriteUtil.INSTANCE.markSpriteActive(atlasManager.method_73030(SAW_VANILLA_TEXTURE));
        SpriteUtil.INSTANCE.markSpriteActive(atlasManager.method_73030(FACTORY_PANEL_TEXTURE));
    }

    @SuppressWarnings("UnstableApiUsage")
    public static void markPonderSpriteActive(PonderLevel world, Selection section) {
        if (DISABLE) {
            return;
        }
        boolean saw = true;
        boolean panel = true;
        Set<class_3611> fluids = new HashSet<>();
        for (class_2338 pos : section) {
            class_2680 state = world.method_8320(pos);
            if (state.method_26215()) {
                continue;
            }
            if (saw && state.method_27852(AllBlocks.MECHANICAL_SAW)) {
                class_11697 atlasManager = class_310.method_1551().method_72703();
                SpriteUtil.INSTANCE.markSpriteActive(atlasManager.method_73030(SAW_TEXTURE));
                SpriteUtil.INSTANCE.markSpriteActive(atlasManager.method_73030(SAW_VANILLA_TEXTURE));
                saw = false;
                continue;
            }
            if (panel && state.method_27852(AllBlocks.FACTORY_GAUGE)) {
                SpriteUtil.INSTANCE.markSpriteActive(class_310.method_1551().method_72703().method_73030(FACTORY_PANEL_TEXTURE));
                panel = false;
                continue;
            }
            if (state.method_26204() instanceof FluidTankBlock && world.method_8321(pos) instanceof FluidTankBlockEntity tank) {
                FluidStack stack = tank.getTankInventory().getFluid();
                if (stack.isEmpty()) {
                    continue;
                }
                class_3611 fluid = stack.getFluid();
                if (fluids.add(fluid)) {
                    markFluidSpriteActive(fluid);
                }
                continue;
            }
            class_3610 fluidState = state.method_26227();
            if (!fluidState.method_15769()) {
                class_3611 fluid = fluidState.method_15772();
                if (fluids.add(fluid)) {
                    markFluidSpriteActive(fluid);
                }
            }
        }
    }

    @SuppressWarnings("UnstableApiUsage")
    public static void markFluidSpriteActive(class_3611 fluid) {
        if (DISABLE) {
            return;
        }
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            SpriteUtil.INSTANCE.markSpriteActive(config.still().get());
            SpriteUtil.INSTANCE.markSpriteActive(config.flowing().get());
        }
    }
}
